@@ -7,14 +7,16 @@ class printr:
         if len(items) == 1:
             message = items[0]
             if isinstance(message, dict) or isinstance(message, list):
-                message = json.dumps(message, indent=4) # Beautify JSON objects
+                try: message = json.dumps(message, indent=4) # Beautify JSON objects
+                except TypeError: pass
         else:
             message = ''
             for item in items:
                 if message:
                     message += ' ' # Add space in between variables
                 if isinstance(item, dict) or isinstance(item, list):
-                    item = json.dumps(item, indent=4)
+                    try: item = json.dumps(item, indent=4) # Beautify JSON objects
+                    except TypeError: pass
                 message += str(item)
         if current_time:
             current_time = datetime.now()
